@@ -11,6 +11,7 @@ import sys
 import datetime
 import traceback
 import redis
+from redisbench_admin.run.git import git_vars_crosscheck
 
 import redisbench_admin.run.metrics
 from redisbench_admin.profilers.perf import PERF_CALLGRAPH_MODE
@@ -30,7 +31,10 @@ from redisbench_admin.run.metrics import (
     from_info_to_overall_shard_cpu,
     collect_cpu_data,
 )
-from redisbench_admin.run.redistimeseries import datasink_profile_tabular_data
+from redisbench_admin.run.redistimeseries import (
+    datasink_profile_tabular_data,
+    timeseries_test_sucess_flow,
+)
 from redisbench_admin.run.run import (
     calculate_client_tool_duration_and_check,
     define_benchmark_plan,
@@ -49,6 +53,7 @@ from redisbench_admin.profilers.profilers_local import (
 from redisbench_admin.utils.benchmark_config import (
     prepare_benchmark_definitions,
     results_dict_kpi_check,
+    get_metadata_tags,
 )
 from redisbench_admin.utils.local import (
     get_local_run_full_filename,
@@ -67,20 +72,29 @@ def run_local_command_logic(args, project_name, project_version):
             project_name=project_name, project_version=project_version
         )
     )
+    tf_github_org = args.github_org
+    tf_github_actor = args.github_actor
+    tf_github_repo = args.github_repo
+    tf_github_sha = args.github_sha
+    tf_github_branch = args.github_branch
+
     (
+        github_actor,
+        github_branch,
         github_org_name,
         github_repo_name,
         github_sha,
-        github_actor,
-        github_branch,
-        github_branch_detached,
-    ) = extract_git_vars()
+    ) = git_vars_crosscheck(
+        tf_github_actor, tf_github_branch, tf_github_org, tf_github_repo, tf_github_sha
+    )
 
     dbdir_folder = args.dbdir_folder
     os.path.abspath(".")
     required_modules = args.required_module
     profilers_enabled = args.enable_profilers
     s3_bucket_name = args.s3_bucket_name
+    flushall_on_every_test_start = args.flushall_on_every_test_start
+    ignore_keyspace_errors = args.ignore_keyspace_errors
     profilers_list = []
     if profilers_enabled:
         profilers_list = args.profilers.split(",")
@@ -125,7 +139,7 @@ def run_local_command_logic(args, project_name, project_version):
         _,
         benchmark_definitions,
         default_metrics,
-        _,
+        exporter_timemetric_path,
         default_specs,
         clusterconfig,
     ) = prepare_benchmark_definitions(args)
@@ -189,6 +203,8 @@ def run_local_command_logic(args, project_name, project_version):
                                     if " " in binary:
                                         binary = binary.split(" ")
                                     (
+                                        result_db_spin,
+                                        artifact_version,
                                         cluster_api_enabled,
                                         redis_conns,
                                         redis_processes,
@@ -204,7 +220,14 @@ def run_local_command_logic(args, project_name, project_version):
                                         required_modules,
                                         setup_type,
                                         shard_count,
+                                        flushall_on_every_test_start,
+                                        ignore_keyspace_errors,
                                     )
+                                    if result_db_spin is False:
+                                        logging.warning(
+                                            "Skipping this test given DB spin stage failed..."
+                                        )
+                                        continue
                                     if benchmark_type == "read-only":
                                         logging.info(
                                             "Given the benchmark for this setup is ready-only we will prepare to reuse it on the next read-only benchmarks (if any )."
@@ -352,6 +375,7 @@ def run_local_command_logic(args, project_name, project_version):
                                     s3_bucket_name,
                                     test_name,
                                 )
+
                                 if (
                                     profilers_enabled
                                     and args.push_results_redistimeseries
@@ -377,7 +401,7 @@ def run_local_command_logic(args, project_name, project_version):
                                     start_time_str,
                                     stdout,
                                 )
-
+                                results_dict = {}
                                 with open(
                                     local_benchmark_output_filename, "r"
                                 ) as json_file:
@@ -395,6 +419,31 @@ def run_local_command_logic(args, project_name, project_version):
                                     return_code = results_dict_kpi_check(
                                         benchmark_config, results_dict, return_code
                                     )
+
+                                metadata_tags = get_metadata_tags(benchmark_config)
+                                (
+                                    _,
+                                    branch_target_tables,
+                                ) = timeseries_test_sucess_flow(
+                                    args.push_results_redistimeseries,
+                                    artifact_version,
+                                    benchmark_config,
+                                    benchmark_duration_seconds,
+                                    0,
+                                    default_metrics,
+                                    setup_name,
+                                    setup_type,
+                                    exporter_timemetric_path,
+                                    results_dict,
+                                    rts,
+                                    start_time_ms,
+                                    test_name,
+                                    github_branch,
+                                    github_org_name,
+                                    github_repo_name,
+                                    tf_triggering_env,
+                                )
+
                                 if setup_details["env"] is None:
                                     if args.keep_env_and_topo is False:
                                         for conn in redis_conns:
