@@ -178,21 +178,29 @@ def run_remote_command_logic(args, project_name, project_version):
             logging.critical("{}. Exiting right away!".format(failure_reason))
             exit(1)
 
+    continue_on_module_check_error = args.continue_on_module_check_error
     module_check_status, error_message = redis_modules_check(local_module_files)
     if module_check_status is False:
-        if webhook_notifications_active:
-            failure_reason = error_message
-            generate_failure_notification(
-                webhook_client_slack,
-                ci_job_name,
-                ci_job_link,
-                failure_reason,
-                tf_github_org,
-                tf_github_repo,
-                tf_github_branch,
-                None,
+        if continue_on_module_check_error is False:
+            if webhook_notifications_active:
+                failure_reason = error_message
+                generate_failure_notification(
+                    webhook_client_slack,
+                    ci_job_name,
+                    ci_job_link,
+                    failure_reason,
+                    tf_github_org,
+                    tf_github_repo,
+                    tf_github_branch,
+                    None,
+                )
+            exit(1)
+        else:
+            logging.error(
+                "the module check failed with the following message {} but you've decided to continue anyway.".format(
+                    error_message
+                )
             )
-        exit(1)
 
     common_properties_log(
         tf_bin_path,
@@ -296,6 +304,11 @@ def run_remote_command_logic(args, project_name, project_version):
     # contains the overall target-tables ( if any target is defined )
     overall_tables = {}
 
+    # Used to only deploy spot once per run
+    spot_instance_error = False
+    ts_key_spot_price = f"ts:{tf_triggering_env}:tests:spot_price"
+    ts_key_full_price = f"ts:{tf_triggering_env}:tests:full_price"
+
     for benchmark_type, bench_by_dataset_map in benchmark_runs_plan.items():
         if return_code != 0 and args.fail_fast:
             logging.warning(
@@ -406,6 +419,9 @@ def run_remote_command_logic(args, project_name, project_version):
                                     db_ssh_port,
                                     client_ssh_port,
                                     username,
+                                    spot_instance_error,
+                                    spot_price_counter,
+                                    full_price_counter,
                                 ) = remote_env_setup(
                                     args,
                                     benchmark_config,
@@ -422,6 +438,9 @@ def run_remote_command_logic(args, project_name, project_version):
                                     tf_timeout_secs,
                                     TF_OVERRIDE_NAME,
                                     TF_OVERRIDE_REMOTE,
+                                    spot_instance_error,
+                                    0,
+                                    0,
                                 )
 
                                 # after we've created the env, even on error we should always teardown
@@ -429,9 +448,28 @@ def run_remote_command_logic(args, project_name, project_version):
                                 try:
                                     (
                                         _,
-                                        _,
+                                        start_time_setup_ms,
                                         testcase_start_time_str,
                                     ) = get_start_time_vars()
+                                    if args.push_results_redistimeseries:
+                                        logging.info(
+                                            f"Updating overall spot price tests counter {ts_key_spot_price}"
+                                        )
+                                        rts.ts().add(
+                                            ts_key_spot_price,
+                                            start_time_setup_ms,
+                                            spot_price_counter,
+                                            duplicate_policy="sum",
+                                        )
+                                        logging.info(
+                                            f"Updating overall spot price full counter {ts_key_spot_price}"
+                                        )
+                                        rts.ts().add(
+                                            ts_key_full_price,
+                                            start_time_setup_ms,
+                                            full_price_counter,
+                                            duplicate_policy="sum",
+                                        )
                                     logname = "{}_{}.log".format(
                                         test_name, testcase_start_time_str
                                     )
@@ -505,6 +543,7 @@ def run_remote_command_logic(args, project_name, project_version):
                                             redis_password,
                                             flushall_on_every_test_start,
                                             ignore_keyspace_errors,
+                                            continue_on_module_check_error,
                                         )
                                         if benchmark_type == "read-only":
                                             ro_benchmark_set(
@@ -759,52 +798,30 @@ def run_remote_command_logic(args, project_name, project_version):
                                                 tf_github_branch, artifact_version
                                             )
                                         ):
-                                            (
-                                                end_time_ms,
-                                                _,
-                                                overall_end_time_metrics,
-                                            ) = collect_redis_metrics(
-                                                redis_conns,
-                                                ["memory"],
-                                                {
-                                                    "memory": [
-                                                        "used_memory",
-                                                        "used_memory_dataset",
-                                                    ]
-                                                },
-                                            )
-                                            if total_shards_cpu_usage is not None:
-                                                overall_end_time_metrics[
-                                                    "total_shards_used_cpu_pct"
-                                                ] = total_shards_cpu_usage
-                                            expire_ms = 7 * 24 * 60 * 60 * 1000
-                                            export_redis_metrics(
-                                                artifact_version,
-                                                end_time_ms,
-                                                overall_end_time_metrics,
-                                                rts,
-                                                setup_name,
-                                                setup_type,
-                                                test_name,
-                                                tf_github_branch,
-                                                tf_github_org,
-                                                tf_github_repo,
-                                                tf_triggering_env,
-                                                {"metric-type": "redis-metrics"},
-                                                expire_ms,
-                                            )
-                                            if collect_commandstats:
+                                            try:
                                                 (
                                                     end_time_ms,
                                                     _,
-                                                    overall_commandstats_metrics,
+                                                    overall_end_time_metrics,
                                                 ) = collect_redis_metrics(
-                                                    redis_conns, ["commandstats"]
+                                                    redis_conns,
+                                                    ["memory"],
+                                                    {
+                                                        "memory": [
+                                                            "used_memory",
+                                                            "used_memory_dataset",
+                                                        ]
+                                                    },
                                                 )
+                                                if total_shards_cpu_usage is not None:
+                                                    overall_end_time_metrics[
+                                                        "total_shards_used_cpu_pct"
+                                                    ] = total_shards_cpu_usage
+                                                expire_ms = 7 * 24 * 60 * 60 * 1000
                                                 export_redis_metrics(
                                                     artifact_version,
                                                     end_time_ms,
-                                                    overall_commandstats_metrics,
+                                                    overall_end_time_metrics,
                                                     rts,
                                                     setup_name,
                                                     setup_type,
@@ -813,30 +830,75 @@ def run_remote_command_logic(args, project_name, project_version):
                                                     tf_github_org,
                                                     tf_github_repo,
                                                     tf_triggering_env,
-                                                    {"metric-type": "commandstats"},
+                                                    {"metric-type": "redis-metrics"},
                                                     expire_ms,
                                                 )
-                                                (
-                                                    end_time_ms,
-                                                    _,
-                                                    overall_commandstats_metrics,
-                                                ) = collect_redis_metrics(
-                                                    redis_conns, ["latencystats"]
+                                                if collect_commandstats:
+                                                    (
+                                                        end_time_ms,
+                                                        _,
+                                                        overall_commandstats_metrics,
+                                                    ) = collect_redis_metrics(
+                                                        redis_conns, ["commandstats"]
+                                                    )
+                                                    export_redis_metrics(
+                                                        artifact_version,
+                                                        end_time_ms,
+                                                        overall_commandstats_metrics,
+                                                        rts,
+                                                        setup_name,
+                                                        setup_type,
+                                                        test_name,
+                                                        tf_github_branch,
+                                                        tf_github_org,
+                                                        tf_github_repo,
+                                                        tf_triggering_env,
+                                                        {"metric-type": "commandstats"},
+                                                        expire_ms,
+                                                    )
+                                                    (
+                                                        end_time_ms,
+                                                        _,
+                                                        overall_commandstats_metrics,
+                                                    ) = collect_redis_metrics(
+                                                        redis_conns, ["latencystats"]
+                                                    )
+                                                    export_redis_metrics(
+                                                        artifact_version,
+                                                        end_time_ms,
+                                                        overall_commandstats_metrics,
+                                                        rts,
+                                                        setup_name,
+                                                        setup_type,
+                                                        test_name,
+                                                        tf_github_branch,
+                                                        tf_github_org,
+                                                        tf_github_repo,
+                                                        tf_triggering_env,
+                                                        {"metric-type": "latencystats"},
+                                                        expire_ms,
+                                                    )
+                                            except (
+                                                redis.exceptions.ConnectionError
+                                            ) as e:
+                                                db_error_artifacts(
+                                                    db_ssh_port,
+                                                    dirname,
+                                                    full_logfiles,
+                                                    logname,
+                                                    private_key,
+                                                    s3_bucket_name,
+                                                    s3_bucket_path,
+                                                    server_public_ip,
+                                                    temporary_dir,
+                                                    args.upload_results_s3,
+                                                    username,
                                                 )
-                                                export_redis_metrics(
-                                                    artifact_version,
-                                                    end_time_ms,
-                                                    overall_commandstats_metrics,
-                                                    rts,
-                                                    setup_name,
-                                                    setup_type,
-                                                    test_name,
-                                                    tf_github_branch,
-                                                    tf_github_org,
-                                                    tf_github_repo,
-                                                    tf_triggering_env,
-                                                    {"metric-type": "latencystats"},
-                                                    expire_ms,
+                                                return_code |= 1
+                                                raise Exception(
+                                                    "Failed to run remote benchmark. {}".format(
+                                                        e.__str__()
+                                                    )
                                                 )
 
                                         if setup_details["env"] is None:
@@ -1026,9 +1088,7 @@ def run_remote_command_logic(args, project_name, project_version):
 
                             else:
                                 logging.info(
-                                    "Test {} does not have remote config. Skipping test.".format(
-                                        test_name
-                                    )
+                                    f"Test {test_name} does not have remote config. Skipping test."
                                 )
 
     if len(benchmark_artifacts_links) > 0:
