@@ -72,6 +72,7 @@ def remote_module_files_cp(
     remote_module_file_dir,
     server_public_ip,
     username,
+    continue_on_module_check_error=False,
 ):
     remote_module_files = []
     if local_module_files is not None:
@@ -94,12 +95,18 @@ def remote_module_files_cp(
             for pos, local_module_file_and_plugin in enumerate(
                 abs_splitted_module_and_plugins, start=1
             ):
+                file_basename = os.path.basename(local_module_file_and_plugin)
                 remote_module_file = "{}/{}".format(
                     remote_module_file_dir,
-                    os.path.basename(local_module_file_and_plugin),
+                    file_basename,
+                )
+                logging.info(
+                    "remote_module_file: {}. basename: {}".format(
+                        remote_module_file, file_basename
+                    )
                 )
                 # copy the module to the DB machine
-                copy_file_to_remote_setup(
+                cp_res = copy_file_to_remote_setup(
                     server_public_ip,
                     username,
                     private_key,
@@ -107,14 +114,24 @@ def remote_module_files_cp(
                     remote_module_file,
                     None,
                     port,
+                    continue_on_module_check_error,
                 )
-                execute_remote_commands(
-                    server_public_ip,
-                    username,
-                    private_key,
-                    ["chmod 755 {}".format(remote_module_file)],
-                    port,
-                )
+                if cp_res:
+                    execute_remote_commands(
+                        server_public_ip,
+                        username,
+                        private_key,
+                        ["chmod 755 {}".format(remote_module_file)],
+                        port,
+                    )
+                else:
+                    # If the copy was unsuccessful restore path to original basename
+                    remote_module_file = file_basename
+                    logging.info(
+                        "Given the copy was unsuccessful restore path to original basename: {}.".format(
+                            remote_module_file
+                        )
+                    )
                 if pos > 1:
                     remote_module_files_in = remote_module_files_in + " "
                 remote_module_files_in = remote_module_files_in + remote_module_file
