@@ -49,6 +49,7 @@ def parse_exporter_timemetric(metric_path: str, results_dict: dict):
         logging.error(
             "Unable to parse time-metric {}. Error: {}".format(metric_path, e.__str__())
         )
+        pass
     return datapoints_timestamp
 
 
@@ -67,6 +68,7 @@ def prepare_benchmark_definitions(args):
 
     (
         default_kpis,
+        default_remote,
         default_metrics,
         exporter_timemetric_path,
         default_specs,
@@ -75,7 +77,7 @@ def prepare_benchmark_definitions(args):
     for usecase_filename in files:
         with open(usecase_filename, "r", encoding="utf8") as stream:
             test_result, benchmark_config, test_name = get_final_benchmark_config(
-                default_kpis, stream, usecase_filename
+                default_kpis, default_remote, stream, usecase_filename
             )
             result &= test_result
             if test_result:
@@ -109,6 +111,7 @@ def get_defaults(defaults_filename):
     default_metrics = []
     exporter_timemetric_path = None
     default_kpis = None
+    default_remote = None
     default_specs = None
     cluster_config = None
     if os.path.exists(defaults_filename):
@@ -118,12 +121,14 @@ def get_defaults(defaults_filename):
             )
             (
                 default_kpis,
+                default_remote,
                 default_metrics,
                 exporter_timemetric_path,
                 default_specs,
                 cluster_config,
             ) = process_default_yaml_properties_file(
                 default_kpis,
+                default_remote,
                 default_metrics,
                 defaults_filename,
                 exporter_timemetric_path,
@@ -131,6 +136,7 @@ def get_defaults(defaults_filename):
             )
     return (
         default_kpis,
+        default_remote,
         default_metrics,
         exporter_timemetric_path,
         default_specs,
@@ -138,7 +144,7 @@ def get_defaults(defaults_filename):
     )
 
 
-def get_final_benchmark_config(default_kpis, stream, usecase_filename):
+def get_final_benchmark_config(default_kpis, default_remote, stream, usecase_filename):
     result = False
     benchmark_config = None
     test_name = None
@@ -150,6 +156,11 @@ def get_final_benchmark_config(default_kpis, stream, usecase_filename):
             merge_default_and_specific_properties_dict_type(
                 benchmark_config, default_kpis, kpis_keyname, usecase_filename
             )
+        kpis_keyname = "remote"
+        if default_remote is not None:
+            merge_default_and_specific_properties_dict_type(
+                benchmark_config, default_remote, kpis_keyname, usecase_filename
+            )
         test_name = benchmark_config["name"]
         result = True
     except Exception as e:
@@ -261,12 +272,24 @@ def extract_redis_dbconfig_parameters(benchmark_config, dbconfig_keyname):
 
 
 def process_default_yaml_properties_file(
-    default_kpis, default_metrics, defaults_filename, exporter_timemetric_path, stream
+    default_kpis,
+    default_remote,
+    default_metrics,
+    defaults_filename,
+    exporter_timemetric_path,
+    stream,
 ):
     default_config = yaml.safe_load(stream)
     default_specs = None
     cluster_config = None
     default_metrics, exporter_timemetric_path = extract_exporter_metrics(default_config)
+    if "remote" in default_config:
+        logging.info(
+            "Loading default REMOTE specifications from file: {}".format(
+                defaults_filename
+            )
+        )
+        default_remote = default_config["remote"]
     if "kpis" in default_config:
         logging.info(
             "Loading default KPIs specifications from file: {}".format(
@@ -288,6 +311,7 @@ def process_default_yaml_properties_file(
         cluster_config = default_config["clusterconfig"]
     return (
         default_kpis,
+        default_remote,
         default_metrics,
         exporter_timemetric_path,
         default_specs,
