@@ -30,7 +30,7 @@ from redisbench_admin.utils.utils import (
 )
 
 # environment variables
-PERFORMANCE_RTS_PUSH = bool(os.getenv("PUSH_RTS", False))
+PERFORMANCE_RTS_PUSH = bool(int(os.getenv("PUSH_RTS", "0")))
 PERFORMANCE_RTS_AUTH = os.getenv("PERFORMANCE_RTS_AUTH", None)
 PERFORMANCE_RTS_USER = os.getenv("PERFORMANCE_RTS_USER", None)
 PERFORMANCE_RTS_HOST = os.getenv("PERFORMANCE_RTS_HOST", "localhost")
@@ -51,7 +51,7 @@ def get_git_root(path):
 
 def view_bar_simple(a, b):
     res = a / int(b) * 100
-    sys.stdout.write("\r    Complete precent: %.2f %%" % res)
+    sys.stdout.write("\r    Complete percent: %.2f %%" % res)
     sys.stdout.flush()
 
 
@@ -63,8 +63,10 @@ def copy_file_to_remote_setup(
     remote_file,
     dirname=None,
     port=22,
+    continue_on_module_check_error=False,
 ):
     full_local_path = local_file
+    res = False
     if dirname is not None:
         full_local_path = "{}/{}".format(dirname, local_file)
     logging.info(
@@ -94,12 +96,20 @@ def copy_file_to_remote_setup(
         )
         res = True
     else:
-        logging.error(
-            "Local file {} does not exists. aborting...".format(full_local_path)
-        )
-        raise Exception(
-            "Local file {} does not exists. aborting...".format(full_local_path)
-        )
+        if continue_on_module_check_error:
+            logging.warning(
+                "Continuing running benchmarks after module check failed on file: {}. Full path {}".format(
+                    local_file, full_local_path
+                )
+            )
+        else:
+            logging.error(
+                "Local file {} does not exists. aborting...".format(full_local_path)
+            )
+
+            raise Exception(
+                "Local file {} does not exists. aborting...".format(full_local_path)
+            )
     return res
 
 
@@ -286,10 +296,15 @@ def setup_remote_environment(
             "github_actor": tf_github_actor,
             "setup_name": tf_setup_name,
             "github_org": tf_github_org,
+            "Project": tf_github_org,
+            "project": tf_github_org,
+            "Environment": tf_github_org,
+            "environment": tf_github_org,
             "github_repo": tf_github_repo,
             "triggering_env": tf_triggering_env,
             "timeout_secs": tf_timeout_secs,
         },
+        raise_on_error=True,
     )
     return retrieve_tf_connection_vars(return_code, tf)
 
@@ -538,13 +553,28 @@ def common_tf(branch, path, repo, temporary_dir=None, destroy=False):
     return terraform_working_dir
 
 
+def check_remote_setup_spot_instance(
+    remote_setup_config,
+):
+    logging.info(f"Checking for spot instance config within... {remote_setup_config}")
+    spot_path = None
+    contains_spot_instance = False
+    for remote_setup_property in remote_setup_config:
+        if "spot_instance" in remote_setup_property:
+            spot_path = "/terraform/" + remote_setup_property["spot_instance"]
+            contains_spot_instance = True
+            logging.info(f"Detected spot instance config. Setup path: {spot_path}")
+
+    return contains_spot_instance, spot_path
+
+
 def fetch_remote_setup_from_config(
     remote_setup_config,
     repo="https://github.com/redis-performance/testing-infrastructure.git",
     branch="master",
     path=None,
 ):
-    setup_type = None
+    setup_type = "oss-standalone"
     setup = None
     if path is None:
         for remote_setup_property in remote_setup_config:
@@ -943,6 +973,10 @@ def get_project_ts_tags(
     tags = {
         "github_org": tf_github_org,
         "github_repo": tf_github_repo,
+        "Project": tf_github_org,
+        "project": tf_github_org,
+        "Environment": tf_github_org,
+        "environment": tf_github_org,
         "github_org/github_repo": "{}/{}".format(tf_github_org, tf_github_repo),
         "deployment_type": deployment_type,
         "deployment_name": deployment_name,
